@@ -41,7 +41,7 @@
 #include "ntqwmatrix.h"
 #include "ntqdatastream.h"
 #include "ntqregion.h"
-#if defined(Q_WS_X11)
+#if defined(TQ_WS_X11)
 double qsincos( double, bool calcCos );		// defined in qpainter_x11.cpp
 #else
 #include <math.h>
@@ -851,7 +851,7 @@ const double deg2rad = 0.017453292519943295769;	// pi/180
 TQWMatrix &TQWMatrix::rotate( double a )
 {
     double b = deg2rad*a;			// convert to radians
-#if defined(Q_WS_X11)
+#if defined(TQ_WS_X11)
     double sina = qsincos(b,FALSE);		// fast and convenient
     double cosa = qsincos(b,TRUE);
 #else
