@@ -87,7 +87,7 @@
 #include "ntqdict.h"
 #include <stdlib.h>
 
-QT_STATIC_CONST_IMPL char * const TQSqlDatabase::defaultConnection = "qt_sql_default_connection";
+const char * const TQSqlDatabase::defaultConnection = "qt_sql_default_connection";
 
 TQPtrDict<TQSqlDriverExtension> *qt_driver_extension_dict = 0;
 TQPtrDict<TQSqlOpenExtension> *qt_open_extension_dict = 0;
@@ -95,7 +95,7 @@ TQPtrDict<TQSqlOpenExtension> *qt_open_extension_dict = 0;
 static TQSingleCleanupHandler< TQPtrDict<TQSqlDriverExtension> > qt_driver_ext_cleanup;
 static TQSingleCleanupHandler< TQPtrDict<TQSqlOpenExtension> > qt_open_ext_cleanup;
 
-Q_EXPORT TQPtrDict<TQSqlDriverExtension> *tqSqlDriverExtDict()
+TQ_EXPORT TQPtrDict<TQSqlDriverExtension> *tqSqlDriverExtDict()
 {
     if ( !qt_driver_extension_dict ) {
 	qt_driver_extension_dict = new TQPtrDict<TQSqlDriverExtension>;
@@ -104,7 +104,7 @@ Q_EXPORT TQPtrDict<TQSqlDriverExtension> *tqSqlDriverExtDict()
     return qt_driver_extension_dict;
 }
 
-Q_EXPORT TQPtrDict<TQSqlOpenExtension> *tqSqlOpenExtDict()
+TQ_EXPORT TQPtrDict<TQSqlOpenExtension> *tqSqlOpenExtDict()
 {
     if ( !qt_open_extension_dict ) {
 	qt_open_extension_dict = new TQPtrDict<TQSqlOpenExtension>;
