@@ -114,7 +114,7 @@ bool KDevDlgFilter::canUnload() const
     return TRUE;
 }
 
-Q_EXPORT_COMPONENT()
+TQ_EXPORT_COMPONENT()
 {
     Q_CREATE_INSTANCE( KDevDlgFilter )
 }
