@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS language="es">
 <context>
     <name>QAccel</name>
     <message>
@@ -1929,7 +1931,7 @@ a
     </message>
     <message>
         <source>letter is expected</source>
-        <translation>se esperaba una  letra</translation>
+        <translation>se esperaba una letra</translation>
     </message>
     <message>
         <source>error occurred while parsing comment</source>
@@ -2000,4 +2002,3 @@ a
     </message>
 </context>
 </TS>
-
